@@ -97,7 +97,6 @@ class CImage():
             self.alpha = (self.alpha / 256).astype(numpy.uint8)
 
         # Read raster bands
-        # self.bands = []
         for band_n in range(1, band_count+1):
             band = gdal_ds.GetRasterBand(band_n)
             array = band.ReadAsArray()
@@ -111,15 +110,14 @@ class CImage():
         self.metadata['projection'] = gdal_ds.GetProjection()
         self.metadata['rpc'] = gdal_ds.GetMetadata('RPC')
 
-    def save(self, filename, options = []):
-        options = list(options)
-        
+    def save(self, filename):        
         band_count = len(self.bands)
         ysize, xsize = self.bands[0].shape
 
+        options = []
         if band_count == 3:
             options.append('PHOTOMETRIC=RGB')
-        
+
         if self.alpha is not None:
             band_count += 1
             options.append('ALPHA=YES')
